@@ -5,7 +5,7 @@
  * of the Apache Software License. See the accompanying LICENSE file
  * for more information.
  *
- * $Id: bpfobj.cc 24 2003-10-24 18:49:33Z jkohen $
+ * $Id: bpfobj.cc 44 2009-02-05 14:09:28Z gera $
  */
 
 #include <pcap.h>
@@ -39,7 +39,7 @@ static PyObject* p_filter(register bpfobject* bpf, PyObject* args);
 
 
 static PyMethodDef bpf_methods[] = {
-  {"filter", (PyCFunction) p_filter, METH_VARARGS, "filter() filters a given packet"},
+  {"filter", (PyCFunction) p_filter, METH_VARARGS, "filter(packet) applies the filter to the packet, returns 0 if there's no match"},
   {NULL, NULL}	/* sentinel */
 };
 
