@@ -5,7 +5,7 @@
  * of the Apache Software License. See the accompanying LICENSE file
  * for more information.
  *
- * $Id: pcapy.cc,v 1.7 2005/12/09 15:07:04 max Exp $
+ * $Id: pcapy.cc 46 2010-08-25 18:06:31Z gutes $
  */
 
 #include <pcap.h>
@@ -14,6 +14,8 @@
 #include "pcapy.h"
 #include "pcapobj.h"
 #include "bpfobj.h"
+#include "pcapdumper.h"
+#include "pcap_pkthdr.h"
 
 
 PyObject *PcapError;
@@ -140,10 +142,10 @@ bpf_compile(PyObject* self, PyObject* args)
   int  snaplen;
   char *filter;
   int optimize;
-  int netmask;
+  unsigned int netmask;
   
   if(!PyArg_ParseTuple(args, 
-		       "iisii:compile",
+		       "iisiI:compile",
 		       &linktype,
 		       &snaplen,
 		       &filter,
@@ -191,6 +193,9 @@ initpcapy(void)
   PyObject *m, *d;
 
   Pcaptype.ob_type =  &PyType_Type;
+  Pkthdr_type.ob_type = &PyType_Type;
+  Pdumpertype.ob_type = &PyType_Type;
+
   m = Py_InitModule3("pcapy", pcap_methods, pcap_doc);
 
   /* Direct from pcap's net/bpf.h. */
